#########################################################################
# SopcastSports
# Daniel Bardsley
# daniel@bardsley.org.uk
# created: 17/12/07
#########################################################################
# parsing.tcl
# All the required parsing is carried out within this file
# Will probably need redesigning as myp2p.eu update their site and
# break this code.
#########################################################################

# parse the nowplaying.xml file from myp2p.eu.
# The file simply lists the current live games so we parse it and
# add each game to the livegames associative array
# This is a callback function for the ::htmlParse library
proc parseNowPlaying {args} {
	global game 

	foreach {tag slash param text} $args {
	
		if { $tag=="title" && $slash == ""} {
			set game $text
		}
			
		if { $tag=="link" && $slash == ""} {
			addgame $game $text
		}
	}
}

# Parses the myp2p.eu page for a specific game and strips all the sopcast streams from a page
# then adds the results to the livegamelinks array
# It seems sloppy to use the current_game_id in this function as this
# is set in loaddata for each game that we are parsing.
# It would be nice if we could grab the name of the here channel too.
proc parseGame {args} {
	global currentgame_id
	global livegames
	
	foreach {tag slash param text} $args {
		if { $tag=="a" && $text=="Play" && $slash=="" && [string first "sop://" "$param"] > -1 } { 
			set trimleft [string first "sop://" "$param"]
			set trimright [expr "[string length $param]-2"]

			set soplink [string range $param $trimleft $trimright]
			puts "\t$soplink"
			addlink $currentgame_id $soplink $livegames($currentgame_id,game)
		}
	}
}

# Parses the output of sp-sc to find: buffer size, up/down speed and nPeers
# Also ensures the stream is removed if it dies.
proc parseSpSc {spsc_stream channel} {
	global openchannels
	
	if {[gets $spsc_stream line]<0} {
		puts "stream died!"
		fileevent $spsc_stream readable ""
		kill_stream $channel
		
		return
	}

	set line [gets $spsc_stream]
	
	# parse buffer size
	if { [string first "nblockAvailable=" "$line"] > -1 } {
		set trimleft [string first "nblockAvailable=" "$line"]
		set trimright [string length $line]
		set trimmed [string range $line $trimleft $trimright]
		set trimleft [string first "=" "$trimmed"]
		set trimleft [expr "$trimleft+1"]
		set trimright [string length $trimmed]
		set bufferlevel [string range $trimmed $trimleft $trimright]
		
		set openchannels($channel,buffer) $bufferlevel
		update_gui $channel
	}
	
	# parse download speed
	if { [string first "downloadRate=" "$line"] > -1 } {

		set trimleft [string first "downloadRate=" "$line"]
		set trimright [string wordend $line [expr "$trimleft+13"]]
		set trimmed [string range $line $trimleft $trimright]
		set trimleft [string first "=" "$trimmed"]
		set trimleft [expr "$trimleft+1"]
		set trimright [string length $trimmed]
		set down [string range $trimmed $trimleft $trimright]
		
		set openchannels($channel,down) $down
		update_gui $channel
	}
	
	#parse upload speed
	if { [string first "uploadRate=" "$line"] > -1 } {

		set trimleft [string first "uploadRate=" "$line"]
		set trimright [string wordend $line [expr "$trimleft+11"]]
		set trimmed [string range $line $trimleft $trimright]
		set trimleft [string first "=" "$trimmed"]
		set trimleft [expr "$trimleft+1"]
		set trimright [string length $trimmed]
		set up [string range $trimmed $trimleft $trimright]
		
		set openchannels($channel,up) $up
		update_gui $channel
	}
	
	# parse peers
	if { [string first "npeers=" "$line"] > -1 } {

		set trimleft [string first "npeers=" "$line"]
		set trimright [string wordend $line [expr "$trimleft+7"]]
		set trimmed [string range $line $trimleft $trimright]
		set trimleft [string first "=" "$trimmed"]
		set trimleft [expr "$trimleft+1"]
		set trimright [string length $trimmed]
		set peers [string range $trimmed $trimleft $trimright]

		set openchannels($channel,nPeers) $peers
		update_gui $channel
	}
	update idletasks
}
