#########################################################################
# SopcastSports
# Daniel Bardsley
# daniel@bardsley.org.uk
# created: 17/12/07
# See bardsley.org.uk for more information
#########################################################################
# TODO:
# Fix inconsistent procedure names (load_streams / loaddata etc.)
# Add support for more than four streams
# Add filtering by sport for list of games
# Add scrollbars to list of games and list of links
# Remove zombie processes caused by killing sp-sc
#########################################################################
# sopcastsports.tcl
# The main SopcastSports file. Load the required libraries and fire up
# the main dialog windows.
#########################################################################

source "parsing.tcl"
source "gamedata.tcl"
source "utils.tcl"
source "gui_events.tcl"
package require htmlparse
package require Tix

global livegames
global livegameslinks
global openchannels
global freechannels
global currentgame_id

# Application entry point
# Build GUI and create data structures
set livegames(ID) -3; #ignore the first two links as these are not events
set livegameslinks(ID) -1
set freechannels {1 2 3 4}

puts "\n-- sopcastsports --"

# Build the GUI
label .lab_livegames -text "Current Live Games"
label .lab_streams -text "Sopcast Streams"
wm title . "SopcastSports v0.1"
wm resizable . FALSE FALSE

global .lst_games
global .lst_streams
listbox .lst_games -selectmode browse -width 40 -height 10 -yscrollcommand {.sbar set}
scrollbar .sbar -orient vertical -command {.lst_games yview}
bind .lst_games <Double-ButtonPress-1> { update_game }
listbox .lst_streams -selectmode single -width 40 -height 5
bind .lst_streams <Double-ButtonPress-1> { load_stream [.lst_streams get [.lst_streams curselection]] }

# build menus
menu .mbar
. config -menu .mbar
.mbar add cascade -label "File" -underline 0 \
	-menu [menu .mbar.file -tearoff 0]
.mbar add cascade -label "View" -underline 0 \
	-menu [menu .mbar.view -tearoff 0]
.mbar add cascade -label "Help" -underline 0 \
	-menu [menu .mbar.help -tearoff 0]
	
set m .mbar.file
$m add command -label "Open Link" -underline 0 \
	-command open_stream_clicked
$m add command -label "Open/Refesh Games" -underline 0 \
	-command push_reload
$m add command -label "Exit" -underline 0 \
	-command exit
	
set m .mbar.view
$m add command -label "Open Streams" -underline 0 \
	-command show_streams

set m .mbar.help
$m add command -label "About" -underline 0 \
	-command about_clicked

grid .lab_livegames -row 1 -column 1 -columnspan 4
grid .lst_games -row 2 -column 1 -columnspan 4
grid .lab_streams -row 3 -column 1 -columnspan 4
grid .lst_streams -row 4 -column 1 -columnspan 4

show_streams

# clear tmp files
exec rm tmp/* -f
